@@ -33,9 +33,10 @@
 #  define KDBUSADDONS_DEPRECATED_NO_EXPORT KDBUSADDONS_NO_EXPORT KDBUSADDONS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KDBUSADDONS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KDBUSADDONS_NO_DEPRECATED
+#    define KDBUSADDONS_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KDBUSADDONS_EXPORT_H */
